@@ -223,16 +223,15 @@ class DomparserResult():
         return self
 
     def _replace_all_links(self, html_code):
-        print("entries:")
-        for kk in self.file_map:
-            print(f"  => {kk}")
         for original_file_name in self.file_map:
             entry = self.file_map[original_file_name]
             path = original_file_name.split('/')
             path = path[len(path)-1].replace('\n', '').replace('\r', '')
-            print(f"Try to replace {path}")
             if entry[0] == 'png':
-                html_code = html_code.replace(f'<A HREF="{path}">', self.output_chart_html(entry[1]) + "<a style='display:none;'>")
+                html_code = html_code.replace(f'<A HREF="{path}">',
+                                              self.output_chart_html(entry[1]) + "<a style='display:none;'>")
+                html_code = html_code.replace(f'<IMG SRC="{path}">',
+                                              self.output_chart_html(entry[1]))
             else:
                 html_code = html_code.replace(f'<A HREF="{path}">', self.html_chart(entry[1]) + "<a style='display:none;'>")
         return html_code
@@ -646,7 +645,7 @@ class Eniam():
                         collect_output = False
                         collect_png = True
                         png_files.append(new_file)
-                        print(f"collect png mode => [{line_content}]")
+                        #print(f"collect png mode => [{line_content}]")
                 if line_content.startswith("@end_pdf@"):
                     collect_pdf = False
                 else:
